@@ -26,7 +26,7 @@ use strict;
 use warnings;
 use Carp;
 
-our($VERSION) = '0.92';
+our($VERSION) = '0.95';
 
 # Debug logging. Uncomment these and all uses of them to activate.
 # It might be nice to make this more easily switchable.
@@ -47,6 +47,8 @@ operations.
 sub open {
     my($class, $fh) = @_;
 
+    binmode($fh);
+
     # read the file header: 32 bytes, plus a mysterious extra
     # four bytes at the front
     my($fheader);
@@ -118,6 +120,8 @@ can be used to create a new file from scratch.
 sub new {
     my($cls, $fh) = @_;
 
+    binmode($fh) if defined($fh);
+
     my($self) = {
 	fh => $fh,
 	toc => { },
